@@ -31,10 +31,7 @@ sub _init {
     my $self = shift;
     return $self->SUPER::_init(@_);
 }
-sub attr {
-    my $self = shift;
-    return $self->_attr;
-}
+
 =head2 session_id
 
 session_id
